import { ApiOptions } from './ApiOptions';
import { DataFormat } from './DataFormat';
/**
 * Request send to the Juracus Document Converter in order to create a machine-readable file for the Juracus AI to analyze.
 *
 * @author Onur Gürsoy
 */
export declare class ApiConvertRequest {
    readonly tasks: ReadonlyMap<string, ApiOptions>;
    readonly gatewayStage: string;
    readonly connectionId: string;
    readonly s3FileUrl: string;
    readonly dataFormat: DataFormat;
    /**
     * Constructs a new {@link ApiConvertRequest} given the specified analysis tasks and the document to convert. The Juracus Document Converter will automatically create an analysis request after converting the document.
     *
     * @param tasks - Mapping from each {@link Criterion} to analyze to options for the specific analysis.
     * @param gatewayStage - Used to differentiate between production and development environments.
     * @param connectionId - Unique identifier pointing to the API user such that the response can be send after finishing the conversion and analysis.
     * @param s3FileUrl - URL pointing to the document the converter should convert.
     * @param dataFormat - Format of the document to convert.
     *
     */
    constructor(tasks: ReadonlyMap<string, ApiOptions>, gatewayStage: string, connectionId: string, s3FileUrl: string, dataFormat: DataFormat);
}
