import { AnalysisResults } from './AnalysisResults';
import { ApiError } from './ApiError';
import { Clause } from './Clause';
import { Criterion } from './Criterion';
/**
 * Response of the Juracus API to an {@link ApiRequest}.
 *
 * @author Onur Gürsoy
 */
export declare class ApiResponse {
    readonly documentText: string;
    readonly results: ReadonlyMap<string, AnalysisResults>;
    readonly errors: readonly ApiError[];
    /**
     * Constructs a new {@link ApiResponse} object as answer to an {@link ApiRequest}.
     *
     * @param documentText - The analyzed text in the (during the request) uploaded file.
     * @param results      - {@link Map} from the UUID of a criterion to the analysis result. Defaults to an empty {@link Map}.
     * @param errors       - {@link Array} of errors which occurred during the process. This parameter defaults to an empty {@link Array}.
     */
    constructor(documentText: string, results: ReadonlyMap<string, AnalysisResults>, errors: readonly ApiError[]);
    readonly getResult: (criterion: Criterion) => AnalysisResults;
    readonly getClauses: (criterion: Criterion) => Clause[];
    readonly hasErrors: () => boolean;
}
