import { ApiOption } from './ApiOption';
/**
 * Options specifying the expected data within the {@link ApiResponse}.
 *
 * @author Onur Gürsoy
 */
export declare class ApiOptions {
    /**
     * {@link Set} of enabled options for a single criterion.
     */
    readonly enabledOptions: Set<ApiOption>;
    /**
     * Constructs a new {@link ApiOptions} object where only the specified options are enabled.
     *
     * @param enabledOptions - {@link Set} of {@link ApiOption} to enable.
     */
    constructor(enabledOptions?: Set<ApiOption>);
    /**
     * Checks whether or not the specified option is enabled.
     *
     * @param option - {@link ApiOption} to check.
     * @return {@code true} if the option is enabled and {@code false} otherwise.
     */
    readonly isEnabled: (option: ApiOption) => boolean;
    /**
     * Checks whether or not the specified option is <strong>not</strong> enabled.
     *
     * @param option - {@link ApiOption} to check.
     * @return {@code true} if the option is not enabled and {@code false} otherwise.
     */
    readonly isDisabled: (option: ApiOption) => boolean;
    /**
     * Enables the specified option.
     *
     * @param option - {@link ApiOption} to enable.
     */
    readonly enable: (option: ApiOption) => boolean;
    /**
     * Disables the specified option.
     *
     * @param option - {@link ApiOption} to disable.
     * @return {@code true} if the option's state changed from enabled to disabled or {@code false} if it was already disabled.
     */
    readonly disable: (option: ApiOption) => boolean;
    readonly set: (option: ApiOption, enabled: boolean) => boolean;
    readonly enableAll: () => boolean;
    readonly disableAll: () => boolean;
}
