export declare class Category {
    readonly id: string;
    readonly name: string;
    /**
     * Security - Category containing all criteria which are connected to information security.
     */
    static readonly SECURITY: Category;
    /**
     * Contract Frame - Category containing all criteria which define basic conditions the contract is subject to.
     */
    static readonly FRAME: Category;
    /**
     * Contract Cancellation and Liability - Category containing all criteria which are part of the contract cancellation or describe liability/warranty or contract penalties.
     */
    static readonly CANCELLATION_AND_LIABILITY: Category;
    /**
     * Constructs a new {@link Category} based on the given UUID as identifier and name.
     *
     * @param id   - UUID of the constructed {@link Category}.
     * @param name - Name or short description of the {@link Category}.
     */
    private constructor();
    static readonly values: () => Category[];
    static readonly set: () => Set<Category>;
    static readonly tryFindById: (uuid: string) => Category;
}
